@@ -26,7 +26,7 @@ class Regression():
     def __init__(self, X:pd.DataFrame, Y, init_in_vars=[], model=None, sample_weight = None, max_related_level=1, iter_num=20,
                  is_train_test_split=True, test_size=0.4, split_num=10, kw_measure_args={},
                  measure = 'ks', max_pvalue_limit=0.05, max_vif_limit=10, max_corr_limit=0.6,seed=666,
-                n_core=None, logger_info=True, logger_file=None, observation_model='normal'):
+                n_core=None, init_dataset=[],logger_info=True, logger_file=None, observation_model='normal'):
         # fit_weight = None, measure_weight = None, kw_measure_args = None,
         # kw_algorithm_class_args = None
 
@@ -43,6 +43,7 @@ class Regression():
         :param max_corr_limit: 皮尔逊相关系数。值越大表示越相关
         :param n_core: 进程数
         :param logger_file: 日志地址
+        :param init_dataset: 测验数据集=[[X_train, X_valid, Y_train, Y_valid],...]
         '''
         if model is None:
             self.model = self._regression
@@ -62,6 +63,7 @@ class Regression():
         self.logger_info = logger_info
         self.logger_file=logger_file
         self.seed=seed
+        self.dataset=init_dataset
         self.in_vars=init_in_vars # 初始默认输入特征
         self.observation_model=observation_model # 'all'代表全变量测试，观测所有特征的效果趋势
         self.is_check_overfit=False
@@ -76,17 +78,19 @@ class Regression():
         self._check_input_data(X,Y)
 
     def _check_input_data(self,X,Y):
-        dataset = []
-        if self.is_trte_split:
-            seed_state = np.random.RandomState(seed=self.seed)
-            seed_set = [int(_ * 10000) for _ in seed_state.rand(self.split_num)]
-            for seed_i in seed_set:
-                X_train, X_valid, Y_train, Y_valid = train_test_split(X, Y, test_size=0.4,random_state=seed_i)
+        if self.dataset==[]:
+            dataset = []
+            if self.is_trte_split:
+                seed_state = np.random.RandomState(seed=self.seed)
+                seed_set = [int(_ * 10000) for _ in seed_state.rand(self.split_num)]
+                for seed_i in seed_set:
+                    X_train, X_valid, Y_train, Y_valid = train_test_split(X, Y, test_size=0.4,random_state=seed_i)
+                    dataset.append([X_train, X_valid, Y_train, Y_valid])
+            else:
+                X_train, X_valid, Y_train, Y_valid = X, Y, X, Y
                 dataset.append([X_train, X_valid, Y_train, Y_valid])
-        else:
-            X_train, X_valid, Y_train, Y_valid = X, Y, X, Y
-            dataset.append([X_train, X_valid, Y_train, Y_valid])
-        self.dataset=dataset
+            self.dataset=dataset
+        assert len(self.dataset[0])==4
         self.columns=dataset[0][0].columns
 
     def _check(self, in_vars, current_perf):
@@ -279,7 +283,7 @@ class Regression():
                     in_vars.append(add_var)
                 current_perf = perf
             if logger_ch:
-                logger_ch.info('此轮迭代完成(全量观察)%d，入模变量为：%s。 当前模型性能%s为:%f' % (iter_idx, add_var, self.measure, current_perf))
+                logger_ch.info('此轮迭代完成(全量观察)%d，入模变量为：%s。 当前模型性能%s为:%f' % (iter_idx, in_vars, self.measure, current_perf))
 
     def _add_observation_var(self, args):
         col = args[0]
